@@ -27,6 +27,9 @@ urlpatterns = patterns('tendenci.addons.corporate_memberships.views',
     url(r"^applications/search/$",
         "corpmembership_search",
         name="corpmembership.search"),
+    url(r"^applications/mycorps/$",
+        "corpmembership_search", {'my_corps_only': True},
+        name="corpmembership.mycorps"),
     url(r"^applications/index/$",
         "index",
         name="corpmembership.index"),
