@@ -537,7 +537,7 @@ def photos_batch_add(request, photoset_id=0):
                 photo.member = request.user
                 photo.safetylevel = 3
                 photo.allow_anonymous_view = True
-                photo.photoset_position = 0
+                photo.position = 0
 
                 # update all permissions and save the model
                 photo = update_perms_and_save(request, photo_form, photo)
@@ -655,7 +655,7 @@ def photos_batch_edit(request, photoset_id=0, template_name="photos/batch-edit.h
 
         # i would like to use the search index here; but it appears that
         # the formset class only accepts a queryset; not a searchqueryset or list
-        photo_qs = Image.objects.filter(photoset=photo_set).order_by("photoset_position")
+        photo_qs = Image.objects.filter(photoset=photo_set).order_by("position")
         photo_formset = PhotoFormSet(queryset=photo_qs)
 
     cc_licenses = License.objects.all()
@@ -685,7 +685,7 @@ def photoset_details(request, id, template_name="photos/photo-set/details.html")
     #    photos = photo_set.get_images(user=request.user).order_by('-pk')
     #else:
     #    photos = photo_set.get_images(user=request.user).order_by('pk')
-    photos = photo_set.get_images(user=request.user).order_by("photoset_position")
+    photos = photo_set.get_images(user=request.user).order_by("position")
     
     EventLog.objects.log(**{
         'event_id': 991500,
